#ifndef PATTERN_COMMANDS_QT_HPP
#define PATTERN_COMMANDS_QT_HPP

/********** Pattern edit **********/
#include "set_key_on_to_step_qt_command.hpp"
#include "set_key_off_to_step_qt_command.hpp"
#include "erase_step_qt_command.hpp"
#include "set_instrument_to_step_qt_command.hpp"
#include "erase_instrument_in_step_qt_command.hpp"
#include "set_volume_to_step_qt_command.hpp"
#include "erase_volume_in_step_qt_command.hpp"
#include "set_effect_id_to_step_qt_command.hpp"
#include "erase_effect_in_step_qt_command.hpp"
#include "set_effect_value_to_step_qt_command.hpp"
#include "erase_effect_value_in_step_qt_command.hpp"
#include "insert_step_qt_command.hpp"
#include "delete_previous_step_qt_command.hpp"
#include "paste_copied_data_to_pattern_qt_command.hpp"
#include "erase_cells_in_pattern_qt_command.hpp"
#include "paste_mix_copied_data_to_pattern_qt_command.hpp"
#include "transpose_note_in_pattern_qt_command.hpp"
#include "expand_pattern_qt_command.hpp"
#include "shrink_pattern_qt_command.hpp"
#include "set_echo_buffer_access_qt_command.hpp"
#include "interpolate_pattern_qt_command.hpp"
#include "reverse_pattern_qt_command.hpp"
#include "replace_instrument_in_pattern_qt_command.hpp"
#include "paste_overwrite_copied_data_to_pattern_qt_command.hpp"
#include "change_values_in_pattern_qt_command.hpp"
#include "paste_insert_copied_data_to_pattern_qt_command.hpp"

#endif // PATTERN_COMMANDS_QT_HPP
